/****************************************************************************
** Meta object code from reading C++ file 'ModuleView.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "ModuleView.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ModuleView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ModuleView_t {
    QByteArrayData data[24];
    char stringdata0[275];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ModuleView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ModuleView_t qt_meta_stringdata_ModuleView = {
    {
QT_MOC_LITERAL(0, 0, 10), // "ModuleView"
QT_MOC_LITERAL(1, 11, 13), // "moduleChanged"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 5), // "state"
QT_MOC_LITERAL(4, 32, 11), // "moduleSaved"
QT_MOC_LITERAL(5, 44, 12), // "closeRequest"
QT_MOC_LITERAL(6, 57, 29), // "showDefaultsIndicatorsChanged"
QT_MOC_LITERAL(7, 87, 4), // "show"
QT_MOC_LITERAL(8, 92, 10), // "loadModule"
QT_MOC_LITERAL(9, 103, 11), // "QModelIndex"
QT_MOC_LITERAL(10, 115, 8), // "menuItem"
QT_MOC_LITERAL(11, 124, 4), // "args"
QT_MOC_LITERAL(12, 129, 10), // "moduleHelp"
QT_MOC_LITERAL(13, 140, 10), // "moduleLoad"
QT_MOC_LITERAL(14, 151, 10), // "moduleSave"
QT_MOC_LITERAL(15, 162, 14), // "moduleDefaults"
QT_MOC_LITERAL(16, 177, 13), // "keyPressEvent"
QT_MOC_LITERAL(17, 191, 10), // "QKeyEvent*"
QT_MOC_LITERAL(18, 202, 5), // "event"
QT_MOC_LITERAL(19, 208, 19), // "activeModuleChanged"
QT_MOC_LITERAL(20, 228, 16), // "KPageWidgetItem*"
QT_MOC_LITERAL(21, 245, 7), // "current"
QT_MOC_LITERAL(22, 253, 8), // "previous"
QT_MOC_LITERAL(23, 262, 12) // "stateChanged"

    },
    "ModuleView\0moduleChanged\0\0state\0"
    "moduleSaved\0closeRequest\0"
    "showDefaultsIndicatorsChanged\0show\0"
    "loadModule\0QModelIndex\0menuItem\0args\0"
    "moduleHelp\0moduleLoad\0moduleSave\0"
    "moduleDefaults\0keyPressEvent\0QKeyEvent*\0"
    "event\0activeModuleChanged\0KPageWidgetItem*\0"
    "current\0previous\0stateChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ModuleView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       4,    0,   77,    2, 0x06 /* Public */,
       5,    0,   78,    2, 0x06 /* Public */,
       6,    1,   79,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    2,   82,    2, 0x0a /* Public */,
      12,    0,   87,    2, 0x0a /* Public */,
      13,    0,   88,    2, 0x0a /* Public */,
      14,    0,   89,    2, 0x0a /* Public */,
      15,    0,   90,    2, 0x0a /* Public */,
      16,    1,   91,    2, 0x0a /* Public */,
      19,    2,   94,    2, 0x08 /* Private */,
      23,    0,   99,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 9, QMetaType::QStringList,   10,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 20, 0x80000000 | 20,   21,   22,
    QMetaType::Void,

       0        // eod
};

void ModuleView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ModuleView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->moduleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->moduleSaved(); break;
        case 2: _t->closeRequest(); break;
        case 3: _t->showDefaultsIndicatorsChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->loadModule((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 5: _t->moduleHelp(); break;
        case 6: _t->moduleLoad(); break;
        case 7: { bool _r = _t->moduleSave();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->moduleDefaults(); break;
        case 9: _t->keyPressEvent((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 10: _t->activeModuleChanged((*reinterpret_cast< KPageWidgetItem*(*)>(_a[1])),(*reinterpret_cast< KPageWidgetItem*(*)>(_a[2]))); break;
        case 11: _t->stateChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ModuleView::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ModuleView::moduleChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ModuleView::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ModuleView::moduleSaved)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ModuleView::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ModuleView::closeRequest)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ModuleView::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ModuleView::showDefaultsIndicatorsChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ModuleView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_ModuleView.data,
    qt_meta_data_ModuleView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ModuleView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModuleView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ModuleView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ModuleView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ModuleView::moduleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ModuleView::moduleSaved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ModuleView::closeRequest()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ModuleView::showDefaultsIndicatorsChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
