#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'externalModule.ui'
**
** Created by: Qt User Interface Compiler version 5.15.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXTERNALMODULE_H
#define UI_EXTERNALMODULE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_ExternalModule
{
public:
    QGridLayout *gridLayout;
    KSqueezedTextLabel *LblText;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;
    QPushButton *PbRelaunch;

    void setupUi(QWidget *ExternalModule)
    {
        if (ExternalModule->objectName().isEmpty())
            ExternalModule->setObjectName(QString::fromUtf8("ExternalModule"));
        ExternalModule->resize(400, 105);
        gridLayout = new QGridLayout(ExternalModule);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        LblText = new KSqueezedTextLabel(ExternalModule);
        LblText->setObjectName(QString::fromUtf8("LblText"));
        LblText->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(LblText, 0, 0, 1, 2);

        horizontalSpacer_4 = new QSpacerItem(120, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(120, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 35, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 1, 1, 1);

        PbRelaunch = new QPushButton(ExternalModule);
        PbRelaunch->setObjectName(QString::fromUtf8("PbRelaunch"));

        gridLayout->addWidget(PbRelaunch, 1, 0, 1, 1);


        retranslateUi(ExternalModule);

        QMetaObject::connectSlotsByName(ExternalModule);
    } // setupUi

    void retranslateUi(QWidget *ExternalModule)
    {
        ExternalModule->setWindowTitle(tr2i18n("Dialog", nullptr));
        PbRelaunch->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ExternalModule: public Ui_ExternalModule {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXTERNALMODULE_H

