/****************************************************************************
** Meta object code from reading C++ file 'BaseMode.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "BaseMode.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BaseMode.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BaseMode_t {
    QByteArrayData data[19];
    char stringdata0[243];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BaseMode_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BaseMode_t qt_meta_stringdata_BaseMode = {
    {
QT_MOC_LITERAL(0, 0, 8), // "BaseMode"
QT_MOC_LITERAL(1, 9, 14), // "actionsChanged"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 11), // "viewChanged"
QT_MOC_LITERAL(4, 37, 5), // "state"
QT_MOC_LITERAL(5, 43, 18), // "changeToolBarItems"
QT_MOC_LITERAL(6, 62, 22), // "BaseMode::ToolBarItems"
QT_MOC_LITERAL(7, 85, 5), // "items"
QT_MOC_LITERAL(8, 91, 13), // "searchChanged"
QT_MOC_LITERAL(9, 105, 4), // "text"
QT_MOC_LITERAL(10, 110, 16), // "addConfiguration"
QT_MOC_LITERAL(11, 127, 14), // "KConfigDialog*"
QT_MOC_LITERAL(12, 142, 6), // "config"
QT_MOC_LITERAL(13, 149, 17), // "loadConfiguration"
QT_MOC_LITERAL(14, 167, 17), // "saveConfiguration"
QT_MOC_LITERAL(15, 185, 15), // "applicationMode"
QT_MOC_LITERAL(16, 201, 15), // "ApplicationMode"
QT_MOC_LITERAL(17, 217, 14), // "SystemSettings"
QT_MOC_LITERAL(18, 232, 10) // "InfoCenter"

    },
    "BaseMode\0actionsChanged\0\0viewChanged\0"
    "state\0changeToolBarItems\0"
    "BaseMode::ToolBarItems\0items\0searchChanged\0"
    "text\0addConfiguration\0KConfigDialog*\0"
    "config\0loadConfiguration\0saveConfiguration\0"
    "applicationMode\0ApplicationMode\0"
    "SystemSettings\0InfoCenter"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BaseMode[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       1,   64, // properties
       1,   67, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,
       3,    1,   50,    2, 0x06 /* Public */,
       5,    1,   53,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   56,    2, 0x0a /* Public */,
      10,    1,   59,    2, 0x0a /* Public */,
      13,    0,   62,    2, 0x0a /* Public */,
      14,    0,   63,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, 0x80000000 | 6,    7,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      15, 0x80000000 | 16, 0x00095409,

 // enums: name, alias, flags, count, data
      16,   16, 0x0,    2,   72,

 // enum data: key, value
      17, uint(BaseMode::SystemSettings),
      18, uint(BaseMode::InfoCenter),

       0        // eod
};

void BaseMode::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BaseMode *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->actionsChanged(); break;
        case 1: _t->viewChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->changeToolBarItems((*reinterpret_cast< BaseMode::ToolBarItems(*)>(_a[1]))); break;
        case 3: _t->searchChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->addConfiguration((*reinterpret_cast< KConfigDialog*(*)>(_a[1]))); break;
        case 5: _t->loadConfiguration(); break;
        case 6: _t->saveConfiguration(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BaseMode::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BaseMode::actionsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BaseMode::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BaseMode::viewChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (BaseMode::*)(BaseMode::ToolBarItems );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BaseMode::changeToolBarItems)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<BaseMode *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< ApplicationMode*>(_v) = _t->applicationMode(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject BaseMode::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_BaseMode.data,
    qt_meta_data_BaseMode,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BaseMode::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BaseMode::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BaseMode.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BaseMode::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void BaseMode::actionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BaseMode::viewChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void BaseMode::changeToolBarItems(BaseMode::ToolBarItems _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
