#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'configDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGDIALOG_H
#define UI_CONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ConfigDialog
{
public:
    QGridLayout *gridLayout;
    QGroupBox *GbViewStyle;
    QCheckBox *ChTooltips;
    QSpacerItem *SpHeight;

    void setupUi(QWidget *ConfigDialog)
    {
        if (ConfigDialog->objectName().isEmpty())
            ConfigDialog->setObjectName(QString::fromUtf8("ConfigDialog"));
        ConfigDialog->resize(491, 141);
        gridLayout = new QGridLayout(ConfigDialog);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        GbViewStyle = new QGroupBox(ConfigDialog);
        GbViewStyle->setObjectName(QString::fromUtf8("GbViewStyle"));

        gridLayout->addWidget(GbViewStyle, 0, 0, 1, 1);

        ChTooltips = new QCheckBox(ConfigDialog);
        ChTooltips->setObjectName(QString::fromUtf8("ChTooltips"));

        gridLayout->addWidget(ChTooltips, 1, 0, 1, 1);

        SpHeight = new QSpacerItem(20, 110, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(SpHeight, 2, 0, 1, 1);


        retranslateUi(ConfigDialog);

        QMetaObject::connectSlotsByName(ConfigDialog);
    } // setupUi

    void retranslateUi(QWidget *ConfigDialog)
    {
        GbViewStyle->setTitle(tr2i18n("View Style", nullptr));
        ChTooltips->setText(tr2i18n("Show detailed tooltips", nullptr));
        (void)ConfigDialog;
    } // retranslateUi

};

namespace Ui {
    class ConfigDialog: public Ui_ConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGDIALOG_H

