// This file is generated by kconfig_compiler_kf5 from systemsettings.kcfg.
// All changes you do to this file will be lost.

#include "BaseConfig.h"

#include <qglobal.h>
#include <QFile>

class BaseConfigHelper
{
  public:
    BaseConfigHelper() : q(nullptr) {}
    ~BaseConfigHelper() { delete q; }
    BaseConfigHelper(const BaseConfigHelper&) = delete;
    BaseConfigHelper& operator=(const BaseConfigHelper&) = delete;
    BaseConfig *q;
};
Q_GLOBAL_STATIC(BaseConfigHelper, s_globalBaseConfig)
BaseConfig *BaseConfig::self()
{
  if (!s_globalBaseConfig()->q) {
    new BaseConfig;
    s_globalBaseConfig()->q->read();
  }

  return s_globalBaseConfig()->q;
}

BaseConfig::BaseConfig( )
  : KConfigSkeleton( QStringLiteral( "systemsettingsrc" ) )
{
  Q_ASSERT(!s_globalBaseConfig()->q);
  s_globalBaseConfig()->q = this;
  setCurrentGroup( QStringLiteral( "Main" ) );

  KConfigSkeleton::ItemBool  *itemShowToolTips;
  itemShowToolTips = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowToolTips" ), mShowToolTips, true );
  itemShowToolTips->setLabel( QCoreApplication::translate("BaseConfig", "Determines whether detailed tooltips should be used") );
  addItem( itemShowToolTips, QStringLiteral( "ShowToolTips" ) );
  KConfigSkeleton::ItemString  *itemActiveView;
  itemActiveView = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ActiveView" ), mActiveView, QStringLiteral( "systemsettings_sidebar_mode" ) );
  itemActiveView->setLabel( QCoreApplication::translate("BaseConfig", "Internal name for the view used") );
  addItem( itemActiveView, QStringLiteral( "ActiveView" ) );
}

BaseConfig::~BaseConfig()
{
  s_globalBaseConfig()->q = nullptr;
}

