/****************************************************************************
** Meta object code from reading C++ file 'SidebarMode.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "SidebarMode.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SidebarMode.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_FocusHackWidget_t {
    QByteArrayData data[4];
    char stringdata0[41];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FocusHackWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FocusHackWidget_t qt_meta_stringdata_FocusHackWidget = {
    {
QT_MOC_LITERAL(0, 0, 15), // "FocusHackWidget"
QT_MOC_LITERAL(1, 16, 9), // "focusNext"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 13) // "focusPrevious"

    },
    "FocusHackWidget\0focusNext\0\0focusPrevious"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FocusHackWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x0a /* Public */,
       3,    0,   25,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void FocusHackWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FocusHackWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->focusNext(); break;
        case 1: _t->focusPrevious(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

QT_INIT_METAOBJECT const QMetaObject FocusHackWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_FocusHackWidget.data,
    qt_meta_data_FocusHackWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FocusHackWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FocusHackWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FocusHackWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int FocusHackWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_SubcategoryModel_t {
    QByteArrayData data[4];
    char stringdata0[37];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SubcategoryModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SubcategoryModel_t qt_meta_stringdata_SubcategoryModel = {
    {
QT_MOC_LITERAL(0, 0, 16), // "SubcategoryModel"
QT_MOC_LITERAL(1, 17, 12), // "titleChanged"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 5) // "title"

    },
    "SubcategoryModel\0titleChanged\0\0title"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SubcategoryModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       1,   20, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

 // properties: name, type, flags
       3, QMetaType::QString, 0x00495001,

 // properties: notify_signal_id
       0,

       0        // eod
};

void SubcategoryModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SubcategoryModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->titleChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SubcategoryModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SubcategoryModel::titleChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<SubcategoryModel *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    Q_UNUSED(_a);
}

QT_INIT_METAOBJECT const QMetaObject SubcategoryModel::staticMetaObject = { {
    QMetaObject::SuperData::link<KSelectionProxyModel::staticMetaObject>(),
    qt_meta_stringdata_SubcategoryModel.data,
    qt_meta_data_SubcategoryModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SubcategoryModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SubcategoryModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SubcategoryModel.stringdata0))
        return static_cast<void*>(this);
    return KSelectionProxyModel::qt_metacast(_clname);
}

int SubcategoryModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KSelectionProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void SubcategoryModel::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_SidebarMode_t {
    QByteArrayData data[41];
    char stringdata0[639];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SidebarMode_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SidebarMode_t qt_meta_stringdata_SidebarMode = {
    {
QT_MOC_LITERAL(0, 0, 11), // "SidebarMode"
QT_MOC_LITERAL(1, 12, 24), // "activeCategoryRowChanged"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 27), // "activeSubCategoryRowChanged"
QT_MOC_LITERAL(4, 66, 22), // "activeSearchRowChanged"
QT_MOC_LITERAL(5, 89, 12), // "widthChanged"
QT_MOC_LITERAL(6, 102, 24), // "actionMenuVisibleChanged"
QT_MOC_LITERAL(7, 127, 23), // "introPageVisibleChanged"
QT_MOC_LITERAL(8, 151, 32), // "defaultsIndicatorsVisibleChanged"
QT_MOC_LITERAL(9, 184, 12), // "moduleLoaded"
QT_MOC_LITERAL(10, 197, 14), // "updateDefaults"
QT_MOC_LITERAL(11, 212, 10), // "initWidget"
QT_MOC_LITERAL(12, 223, 34), // "toggleDefaultsIndicatorsVisib..."
QT_MOC_LITERAL(13, 258, 6), // "action"
QT_MOC_LITERAL(14, 265, 8), // "QAction*"
QT_MOC_LITERAL(15, 274, 4), // "name"
QT_MOC_LITERAL(16, 279, 14), // "actionIconName"
QT_MOC_LITERAL(17, 294, 14), // "requestToolTip"
QT_MOC_LITERAL(18, 309, 11), // "QModelIndex"
QT_MOC_LITERAL(19, 321, 5), // "index"
QT_MOC_LITERAL(20, 327, 4), // "rect"
QT_MOC_LITERAL(21, 332, 22), // "requestMostUsedToolTip"
QT_MOC_LITERAL(22, 355, 11), // "hideToolTip"
QT_MOC_LITERAL(23, 367, 19), // "hideMostUsedToolTip"
QT_MOC_LITERAL(24, 387, 14), // "showActionMenu"
QT_MOC_LITERAL(25, 402, 8), // "position"
QT_MOC_LITERAL(26, 411, 10), // "loadModule"
QT_MOC_LITERAL(27, 422, 12), // "activeModule"
QT_MOC_LITERAL(28, 435, 4), // "args"
QT_MOC_LITERAL(29, 440, 13), // "categoryModel"
QT_MOC_LITERAL(30, 454, 19), // "QAbstractItemModel*"
QT_MOC_LITERAL(31, 474, 11), // "searchModel"
QT_MOC_LITERAL(32, 486, 16), // "subCategoryModel"
QT_MOC_LITERAL(33, 503, 13), // "mostUsedModel"
QT_MOC_LITERAL(34, 517, 17), // "activeCategoryRow"
QT_MOC_LITERAL(35, 535, 15), // "activeSearchRow"
QT_MOC_LITERAL(36, 551, 20), // "activeSubCategoryRow"
QT_MOC_LITERAL(37, 572, 5), // "width"
QT_MOC_LITERAL(38, 578, 17), // "actionMenuVisible"
QT_MOC_LITERAL(39, 596, 16), // "introPageVisible"
QT_MOC_LITERAL(40, 613, 25) // "defaultsIndicatorsVisible"

    },
    "SidebarMode\0activeCategoryRowChanged\0"
    "\0activeSubCategoryRowChanged\0"
    "activeSearchRowChanged\0widthChanged\0"
    "actionMenuVisibleChanged\0"
    "introPageVisibleChanged\0"
    "defaultsIndicatorsVisibleChanged\0"
    "moduleLoaded\0updateDefaults\0initWidget\0"
    "toggleDefaultsIndicatorsVisibility\0"
    "action\0QAction*\0name\0actionIconName\0"
    "requestToolTip\0QModelIndex\0index\0rect\0"
    "requestMostUsedToolTip\0hideToolTip\0"
    "hideMostUsedToolTip\0showActionMenu\0"
    "position\0loadModule\0activeModule\0args\0"
    "categoryModel\0QAbstractItemModel*\0"
    "searchModel\0subCategoryModel\0mostUsedModel\0"
    "activeCategoryRow\0activeSearchRow\0"
    "activeSubCategoryRow\0width\0actionMenuVisible\0"
    "introPageVisible\0defaultsIndicatorsVisible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SidebarMode[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
      11,  154, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  114,    2, 0x06 /* Public */,
       3,    0,  115,    2, 0x06 /* Public */,
       4,    0,  116,    2, 0x06 /* Public */,
       5,    0,  117,    2, 0x06 /* Public */,
       6,    0,  118,    2, 0x06 /* Public */,
       7,    0,  119,    2, 0x06 /* Public */,
       8,    0,  120,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,  121,    2, 0x08 /* Private */,
      10,    0,  122,    2, 0x08 /* Private */,
      11,    0,  123,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      12,    0,  124,    2, 0x02 /* Public */,
      13,    1,  125,    2, 0x02 /* Public */,
      16,    1,  128,    2, 0x02 /* Public */,
      17,    2,  131,    2, 0x02 /* Public */,
      21,    2,  136,    2, 0x02 /* Public */,
      22,    0,  141,    2, 0x02 /* Public */,
      23,    0,  142,    2, 0x02 /* Public */,
      24,    1,  143,    2, 0x02 /* Public */,
      26,    2,  146,    2, 0x02 /* Public */,
      26,    1,  151,    2, 0x22 /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void,
    0x80000000 | 14, QMetaType::QString,   15,
    QMetaType::QString, QMetaType::QString,   15,
    QMetaType::Void, 0x80000000 | 18, QMetaType::QRectF,   19,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::QRectF,   19,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   25,
    QMetaType::Void, 0x80000000 | 18, QMetaType::QStringList,   27,   28,
    QMetaType::Void, 0x80000000 | 18,   27,

 // properties: name, type, flags
      29, 0x80000000 | 30, 0x00095409,
      31, 0x80000000 | 30, 0x00095409,
      32, 0x80000000 | 30, 0x00095409,
      33, 0x80000000 | 30, 0x00095409,
      34, QMetaType::Int, 0x00495001,
      35, QMetaType::Int, 0x00495001,
      36, QMetaType::Int, 0x00495001,
      37, QMetaType::Int, 0x00495001,
      38, QMetaType::Bool, 0x00495001,
      39, QMetaType::Bool, 0x00495103,
      40, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       2,
       1,
       3,
       4,
       5,
       6,

       0        // eod
};

void SidebarMode::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SidebarMode *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->activeCategoryRowChanged(); break;
        case 1: _t->activeSubCategoryRowChanged(); break;
        case 2: _t->activeSearchRowChanged(); break;
        case 3: _t->widthChanged(); break;
        case 4: _t->actionMenuVisibleChanged(); break;
        case 5: _t->introPageVisibleChanged(); break;
        case 6: _t->defaultsIndicatorsVisibleChanged(); break;
        case 7: _t->moduleLoaded(); break;
        case 8: _t->updateDefaults(); break;
        case 9: _t->initWidget(); break;
        case 10: _t->toggleDefaultsIndicatorsVisibility(); break;
        case 11: { QAction* _r = _t->action((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QAction**>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->actionIconName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->requestToolTip((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QRectF(*)>(_a[2]))); break;
        case 14: _t->requestMostUsedToolTip((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QRectF(*)>(_a[2]))); break;
        case 15: _t->hideToolTip(); break;
        case 16: _t->hideMostUsedToolTip(); break;
        case 17: _t->showActionMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 18: _t->loadModule((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 19: _t->loadModule((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SidebarMode::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SidebarMode::activeCategoryRowChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SidebarMode::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SidebarMode::activeSubCategoryRowChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (SidebarMode::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SidebarMode::activeSearchRowChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (SidebarMode::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SidebarMode::widthChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (SidebarMode::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SidebarMode::actionMenuVisibleChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (SidebarMode::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SidebarMode::introPageVisibleChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (SidebarMode::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SidebarMode::defaultsIndicatorsVisibleChanged)) {
                *result = 6;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<SidebarMode *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QAbstractItemModel**>(_v) = _t->categoryModel(); break;
        case 1: *reinterpret_cast< QAbstractItemModel**>(_v) = _t->searchModel(); break;
        case 2: *reinterpret_cast< QAbstractItemModel**>(_v) = _t->subCategoryModel(); break;
        case 3: *reinterpret_cast< QAbstractItemModel**>(_v) = _t->mostUsedModel(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->activeCategoryRow(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->activeSearchRow(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->activeSubCategoryRow(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->width(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->actionMenuVisible(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->introPageVisible(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->defaultsIndicatorsVisible(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<SidebarMode *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 9: _t->setIntroPageVisible(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject SidebarMode::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseMode::staticMetaObject>(),
    qt_meta_stringdata_SidebarMode.data,
    qt_meta_data_SidebarMode,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SidebarMode::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SidebarMode::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SidebarMode.stringdata0))
        return static_cast<void*>(this);
    return BaseMode::qt_metacast(_clname);
}

int SidebarMode::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseMode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 20;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 11;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void SidebarMode::activeCategoryRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SidebarMode::activeSubCategoryRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SidebarMode::activeSearchRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SidebarMode::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SidebarMode::actionMenuVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SidebarMode::introPageVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SidebarMode::defaultsIndicatorsVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
