
#ifndef SYSTEMSETTINGSVIEW_EXPORT_H
#define SYSTEMSETTINGSVIEW_EXPORT_H

#ifdef SYSTEMSETTINGSVIEW_STATIC_DEFINE
#  define SYSTEMSETTINGSVIEW_EXPORT
#  define SYSTEMSETTINGSVIEW_NO_EXPORT
#else
#  ifndef SYSTEMSETTINGSVIEW_EXPORT
#    ifdef systemsettingsview_EXPORTS
        /* We are building this library */
#      define SYSTEMSETTINGSVIEW_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define SYSTEMSETTINGSVIEW_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef SYSTEMSETTINGSVIEW_NO_EXPORT
#    define SYSTEMSETTINGSVIEW_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef SYSTEMSETTINGSVIEW_DEPRECATED
#  define SYSTEMSETTINGSVIEW_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef SYSTEMSETTINGSVIEW_DEPRECATED_EXPORT
#  define SYSTEMSETTINGSVIEW_DEPRECATED_EXPORT SYSTEMSETTINGSVIEW_EXPORT SYSTEMSETTINGSVIEW_DEPRECATED
#endif

#ifndef SYSTEMSETTINGSVIEW_DEPRECATED_NO_EXPORT
#  define SYSTEMSETTINGSVIEW_DEPRECATED_NO_EXPORT SYSTEMSETTINGSVIEW_NO_EXPORT SYSTEMSETTINGSVIEW_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef SYSTEMSETTINGSVIEW_NO_DEPRECATED
#    define SYSTEMSETTINGSVIEW_NO_DEPRECATED
#  endif
#endif

#endif /* SYSTEMSETTINGSVIEW_EXPORT_H */
