// This file is generated by kconfig_compiler_kf5 from systemsettings.kcfg.
// All changes you do to this file will be lost.
#ifndef BASECONFIG_H
#define BASECONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class BaseConfig : public KConfigSkeleton
{
  public:

    static BaseConfig *self();
    ~BaseConfig();

    /**
      Set Determines whether detailed tooltips should be used
    */
    static
    void setShowToolTips( bool v )
    {
      if (!self()->isShowToolTipsImmutable())
        self()->mShowToolTips = v;
    }

    /**
      Get Determines whether detailed tooltips should be used
    */
    static
    bool showToolTips()
    {
      return self()->mShowToolTips;
    }

    /**
      Is Determines whether detailed tooltips should be used Immutable
    */
    static
    bool isShowToolTipsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShowToolTips" ) );
    }

    /**
      Set Internal name for the view used
    */
    static
    void setActiveView( const QString & v )
    {
      if (!self()->isActiveViewImmutable())
        self()->mActiveView = v;
    }

    /**
      Get Internal name for the view used
    */
    static
    QString activeView()
    {
      return self()->mActiveView;
    }

    /**
      Is Internal name for the view used Immutable
    */
    static
    bool isActiveViewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ActiveView" ) );
    }

  protected:
    BaseConfig();
    friend class BaseConfigHelper;


    // Main
    bool mShowToolTips;
    QString mActiveView;

  private:
};

#endif

