/****************************************************************************
** Meta object code from reading C++ file 'SettingsBase.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "SettingsBase.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SettingsBase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SettingsBase_t {
    QByteArrayData data[25];
    char stringdata0[291];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SettingsBase_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SettingsBase_t qt_meta_stringdata_SettingsBase = {
    {
QT_MOC_LITERAL(0, 0, 12), // "SettingsBase"
QT_MOC_LITERAL(1, 13, 15), // "initApplication"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 11), // "initToolBar"
QT_MOC_LITERAL(4, 42, 12), // "initHelpMenu"
QT_MOC_LITERAL(5, 55, 10), // "initConfig"
QT_MOC_LITERAL(6, 66, 12), // "initMenuList"
QT_MOC_LITERAL(7, 79, 9), // "MenuItem*"
QT_MOC_LITERAL(8, 89, 6), // "parent"
QT_MOC_LITERAL(9, 96, 13), // "configUpdated"
QT_MOC_LITERAL(10, 110, 10), // "configShow"
QT_MOC_LITERAL(11, 121, 5), // "about"
QT_MOC_LITERAL(12, 127, 12), // "changePlugin"
QT_MOC_LITERAL(13, 140, 10), // "viewChange"
QT_MOC_LITERAL(14, 151, 5), // "state"
QT_MOC_LITERAL(15, 157, 17), // "updateViewActions"
QT_MOC_LITERAL(16, 175, 13), // "changeToolBar"
QT_MOC_LITERAL(17, 189, 22), // "BaseMode::ToolBarItems"
QT_MOC_LITERAL(18, 212, 7), // "toolbar"
QT_MOC_LITERAL(19, 220, 15), // "changeAboutMenu"
QT_MOC_LITERAL(20, 236, 17), // "const KAboutData*"
QT_MOC_LITERAL(21, 254, 9), // "menuAbout"
QT_MOC_LITERAL(22, 264, 8), // "QAction*"
QT_MOC_LITERAL(23, 273, 8), // "menuItem"
QT_MOC_LITERAL(24, 282, 8) // "fallback"

    },
    "SettingsBase\0initApplication\0\0initToolBar\0"
    "initHelpMenu\0initConfig\0initMenuList\0"
    "MenuItem*\0parent\0configUpdated\0"
    "configShow\0about\0changePlugin\0viewChange\0"
    "state\0updateViewActions\0changeToolBar\0"
    "BaseMode::ToolBarItems\0toolbar\0"
    "changeAboutMenu\0const KAboutData*\0"
    "menuAbout\0QAction*\0menuItem\0fallback"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SettingsBase[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x08 /* Private */,
       3,    0,   80,    2, 0x08 /* Private */,
       4,    0,   81,    2, 0x08 /* Private */,
       5,    0,   82,    2, 0x08 /* Private */,
       6,    1,   83,    2, 0x08 /* Private */,
       9,    0,   86,    2, 0x08 /* Private */,
      10,    0,   87,    2, 0x08 /* Private */,
      11,    0,   88,    2, 0x08 /* Private */,
      12,    0,   89,    2, 0x08 /* Private */,
      13,    1,   90,    2, 0x08 /* Private */,
      15,    0,   93,    2, 0x08 /* Private */,
      16,    1,   94,    2, 0x08 /* Private */,
      19,    3,   97,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 20, 0x80000000 | 22, QMetaType::QString,   21,   23,   24,

       0        // eod
};

void SettingsBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SettingsBase *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->initApplication(); break;
        case 1: _t->initToolBar(); break;
        case 2: _t->initHelpMenu(); break;
        case 3: _t->initConfig(); break;
        case 4: _t->initMenuList((*reinterpret_cast< MenuItem*(*)>(_a[1]))); break;
        case 5: _t->configUpdated(); break;
        case 6: _t->configShow(); break;
        case 7: _t->about(); break;
        case 8: _t->changePlugin(); break;
        case 9: _t->viewChange((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->updateViewActions(); break;
        case 11: _t->changeToolBar((*reinterpret_cast< BaseMode::ToolBarItems(*)>(_a[1]))); break;
        case 12: _t->changeAboutMenu((*reinterpret_cast< const KAboutData*(*)>(_a[1])),(*reinterpret_cast< QAction*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MenuItem* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SettingsBase::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_meta_stringdata_SettingsBase.data,
    qt_meta_data_SettingsBase,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SettingsBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SettingsBase.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int SettingsBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
